{ inputs, pkgs, ... }:
let

  k-vars = ''
(defvar
  tap-timeout   150
  hold-timeout  200)
'';
  shared-alias = ''
(defalias
  supesc (tap-hold-press $tap-timeout $hold-timeout esc lmet)

  hyper (multi lsft lctl lalt lmet)

  ;; ctrl return
  ctrl-ret (tap-hold-press $tap-timeout $hold-timeout ret lctl)

  ;; layer mods
  spcnav (tap-hold $tap-timeout 300 spc (layer-while-held navigation))

  ;; space cadet shift
  sp-lsft (tap-hold-press $tap-timeout $hold-timeout S-9 lsft)
  sp-rsft (tap-hold-press $tap-timeout $hold-timeout S-0 lsft)

  ;; home-row mods
  a (tap-hold $tap-timeout $hold-timeout a lshift)
  s (tap-hold $tap-timeout $hold-timeout s lalt)
  d (tap-hold $tap-timeout $hold-timeout d lctrl)

  ;; tap-dance for common combos
  tap-copy (tap-dance 150 (c C-c))
  tap-paste (tap-dance 150 (v C-v))
  tap-paste-p (tap-dance 150 (p C-v))
  tap-undo (tap-dance 150 (u C-z))
)
'';
  basic-nav = ''
  y home
  u pgdn
  i pgup
  o end

  h left
  j down
  k up
  l right

  n C-left
  m C-down
  , C-up
  . C-right
'';
in
{
  environment.systemPackages = [
    pkgs.kanata
  ];

  # Add the Kanata service user to necessary groups
  systemd.services.kanata-razer.serviceConfig = {
    SupplementaryGroups = [
      "input"
      "uinput"
      "openrazer"
    ];
  };

  services.kanata = {
    enable = true;

    keyboards = {
      raise = {
        devices = [ "/dev/input/by-id/usb-DYGMA_RAISE2_012310010BFAE7C9-if02-event-kbd" ];
        extraDefCfg = ''
process-unmapped-keys yes
concurrent-tap-hold yes
allow-hardware-repeat false
'';

        config = ''
(defsrc
 esc   1    2    3    4    5    6    7    8    9    0    -    =  bspc
 tab  q    w    e    r    t    y    u    i    o    p    [    ]    \
 caps a    s    d    f    g    h    j    k    l    ;    '    ret
 lsft z    x    c    v    b    n    m    ,    .    /    rsft
 lctl lmet lalt f23     ins  spc       f24 ralt rmet menu rctrl
                        f19 f20 f21 f22)

${k-vars}

${shared-alias}

(defalias
  controls (layer-while-held media-controls))

(deflayer base
  grv  1    2    3    4    5    6    7    8    9    0    -    = bspc
  tab  q    w    e    r    t    y    u    i    o   p    [    ]  \
  @supesc @a    @s    @d    f    g    h    j    k    l    ;    '    ret
  @sp-lsft z    x    c    v    b    n    m    ,    .    /    @sp-rsft
  @hyper @controls lalt lctrl   @spcnav      @spcnav    rctrl ralt @controls @hyper @supesc
                             mlft mrgt del bspc)

(deflayermap (navigation)
  1 f1
  2 f2
  3 f3
  4 f4
  5 f5
  6 f6
  7 f7
  8 f8
  9 f9
  0 f10
  - f11
  = f12

  ${basic-nav}

  rsft up
  menu down
  rmet left
  rctrl right
  ___ _)

(deflayermap (media-controls)
  1 VolumeMute
  2 VolumeDown
  3 VolumeUp
  5 MediaTrackPrevious
  6 MediaPlayPause
  7 MediaTrackNext

  8 brdown
  9 brup
  0 bldn
  - blup

  h MediaTrackPrevious
  j VolumeDown
  k VolumeUp
  l MediaTrackNext
  ; MediaPlayPause
  ___ _)

'';
      };

      razer = {
        devices = [ "/dev/input/by-id/usb-Razer_Razer_Blade-event-kbd"
                    "/dev/input/by-id/usb-Razer_Razer_Blade-if01-event-kbd" ];
        extraDefCfg = ''
process-unmapped-keys yes
concurrent-tap-hold yes
allow-hardware-repeat false
'';
        config = ''
(defsrc
  grv  1    2    3    4    5    6    7    8    9    0    -    =    bspc
  tab  q    w    e    r    t    y    u    i    o    p    [    ]    \
  caps a    s    d    f    g    h    j    k    l    ;    '    ret
  lsft z    x    c    v    b    n    m    ,    .    /    rsft
  lctrl lmet lalt           spc            ralt rctrl)

${k-vars}

${shared-alias}

(deflayer base
  grv  1    2    3    4    5    6    7    8    9    0    -    =    bspc
  tab  q    w    e    r    t    y     u    i    o   p    [    ]    \
  @supesc  @a    @s    @d    f    g    h    j    k    l    ;    '    ret
  @sp-lsft z    x    c    v   b    n    m    ,    .    /    @sp-rsft
  @supesc lalt @ctrl-ret     @spcnav            @ctrl-ret ralt)

(deflayermap (navigation)
  ${basic-nav}
  ___ _)

'';
      };
    };
  };
}
